"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
var getDocument = exports.getDocument = function getDocument(elm) {
  return (elm || {}).ownerDocument || document;
};
var getWindow = exports.getWindow = function getWindow(elm) {
  return (getDocument(elm) || {}).defaultView || window;
};
var isHTMLElement = exports.isHTMLElement = function isHTMLElement(elm) {
  return elm instanceof HTMLElement || elm instanceof getWindow(elm).HTMLElement;
};
var isHTMLCanvasElement = exports.isHTMLCanvasElement = function isHTMLCanvasElement(elm) {
  return elm instanceof HTMLCanvasElement || elm instanceof getWindow(elm).HTMLCanvasElement;
};
var asElement = exports.asElement = function asElement(x) {
  return x;
};
var getPageFromElement = exports.getPageFromElement = function getPageFromElement(target) {
  var node = asElement(target.closest(".page"));

  if (!node || !isHTMLElement(node)) {
    return null;
  }

  var number = Number(asElement(node).dataset.pageNumber);
  return {
    node: node,
    number: number
  };
};
var getPageFromRange = exports.getPageFromRange = function getPageFromRange(range) {
  var parentElement = range.startContainer.parentElement;

  if (!isHTMLElement(parentElement)) {
    return;
  }

  return getPageFromElement(asElement(parentElement));
};
var findOrCreateContainerLayer = exports.findOrCreateContainerLayer = function findOrCreateContainerLayer(container, className) {
  var doc = getDocument(container);
  var layer = container.querySelector("." + className);

  if (!layer) {
    layer = doc.createElement("div");
    layer.className = className;
    container.appendChild(layer);
  }

  return layer;
};